@@ -1,4 +1,15 @@
 # (C) Copyright 2015 Hewlett Packard Enterprise Development Company LP
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 
 import logging
 import os
@@ -26,9 +37,17 @@ class HAProxy(monasca_setup.detection.Plugin):
         config = monasca_setup.agent_config.Plugins()
         log.info("\tEnabling HAProxy process watching")
 
-        config.merge(monasca_setup.detection.watch_process(['haproxy'], 'haproxy', exact_match=False))
+        config.merge(
+            monasca_setup.detection.watch_process(
+                ['haproxy'],
+                'haproxy',
+                exact_match=False))
         if monasca_setup.detection.find_process_cmdline('keepalived') is not None:
-            config.merge(monasca_setup.detection.watch_process(['keepalived'], 'haproxy', exact_match=False))
+            config.merge(
+                monasca_setup.detection.watch_process(
+                    ['keepalived'],
+                    'haproxy',
+                    exact_match=False))
 
         proxy_cfgfile = '/etc/haproxy/haproxy.cfg'
         if os.path.exists(proxy_cfgfile):
@@ -41,7 +60,7 @@ class HAProxy(monasca_setup.detection.Plugin):
             password = None
             for line in proxy_cfg.splitlines():
                 if line.startswith('listen'):
-                    listen_match = re.search('^listen.*stats\S*\s(.*)', line)
+                    listen_match = re.search(r'^listen.*stats\S*\s(.*)', line)
                     if listen_match is None:
                         continue
                     listen_socket = listen_match.group(1).split(':', 1)
@@ -52,16 +71,22 @@ class HAProxy(monasca_setup.detection.Plugin):
                     port = listen_socket[1].strip()
                     url = 'http://{0}:{1}'.format(host, port)
                 if url is not None and line.strip().startswith('stats auth'):
-                    auth = re.search('stats auth\s(.*)', line).group(1).split(':')
+                    auth = re.search(r'stats auth\s(.*)', line).group(1).split(':')
                     user = auth[0].strip()
                     password = auth[1].strip()
 
             if url is None:
-                log.warn('Unable to parse haproxy config for stats url, skipping HAProxy check plugin configuration')
+                log.warn(
+                    'Unable to parse haproxy config for stats url, skipping HAProxy check plugin'
+                    'configuration')
             else:
                 log.info('Enabling the HAProxy check plugin')
-                instance_config = {'name': url, 'url': url, 'status_check': False, 'collect_service_stats_only': True,
-                                   'collect_status_metrics': False}
+                instance_config = {
+                    'name': url,
+                    'url': url,
+                    'status_check': False,
+                    'collect_service_stats_only': True,
+                    'collect_status_metrics': False}
                 if user is not None:
                     instance_config['username'] = user
                 if password is not None:
